==> libtorrent_0.11.9.orig.tar.gz: libtorrent-0.11.9/src/protocol/peer_factory.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2007, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "peer_factory.h"
#include "peer_connection_leech.h"
#include "peer_connection_seed.h"

namespace torrent {

PeerConnectionBase*
createPeerConnectionDefault(bool encrypted) {
  PeerConnectionBase* pc = new PeerConnectionLeech;

  return pc;
}

PeerConnectionBase*
createPeerConnectionSeed(bool encrypted) {
  PeerConnectionBase* pc;
  if (encrypted)
    pc = new PeerConnectionLeech;   // PCS doesn't have encryption support
  else
    pc = new PeerConnectionSeed;

  return pc;
}

}

==> libtorrent-0.12.6.tar.gz: libtorrent-0.12.6/src/protocol/peer_factory.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2007, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "peer_factory.h"
#include "peer_connection_leech.h"

namespace torrent {

PeerConnectionBase*
createPeerConnectionDefault(bool encrypted) {
  PeerConnectionBase* pc = new PeerConnection<Download::CONNECTION_LEECH>;

  return pc;
}

PeerConnectionBase*
createPeerConnectionSeed(bool encrypted) {
  PeerConnectionBase* pc = new PeerConnection<Download::CONNECTION_SEED>;

  return pc;
}

PeerConnectionBase*
createPeerConnectionInitialSeed(bool encrypted) {
  PeerConnectionBase* pc = new PeerConnection<Download::CONNECTION_INITIAL_SEED>;

  return pc;
}

}
